@@ -1,16 +1,16 @@
 /* bjb-note-id.c
  * Copyright (C) Pierre-Yves LUYTEN 2012 <py@luyten.fr>
- * 
+ *
  * bijiben is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * bijiben is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -228,7 +228,8 @@ biji_note_id_get_title (BijiNoteID* n)
 
 
 gboolean
-biji_note_id_set_content (BijiNoteID *id, gchar *content)
+biji_note_id_set_content (BijiNoteID *id,
+                          const gchar *content)
 {
   g_return_val_if_fail (BIJI_IS_NOTE_ID (id), FALSE);
   g_return_val_if_fail ((content != NULL), FALSE);
